<?php declare(strict_types=1);

namespace App\Form;

use App\Entity\MenuItem;
use Override;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;
use Symfony\Component\Validator\Constraints\GreaterThanOrEqual;

class MenuItemType extends AbstractType
{
    #[Override]
    public function buildForm(FormBuilderInterface $builder, array $options): void
    {
        $builder
            ->add(child: 'name', type: TextType::class, options: [
                'mapped' => false,
            ])
            ->add(
                child: 'price',
                options: [
                    'label' => 'Price in cents',
                    'constraints' => [
                        new GreaterThanOrEqual([
                            'value' => 0,
                            'message' => 'The price must be a positive number or zero.',
                        ]),
                    ],
                ],
            );
    }

    #[Override]
    public function configureOptions(OptionsResolver $resolver): void
    {
        $resolver->setDefaults([
            'data_class' => MenuItem::class,
        ]);
    }
}
